View source: R/summary.InteractionClassification.R View source: R/summary.payoffs.R
| summary | R Documentation |
Computes summary statistics by classification group from an object of class
InteractionClassification, including mean differences in viral load and CD4 counts,
and the number of observations per cluster.
This function summarizes the payoffs object by classification.
summary(object, ...)
summary(object, ...)
object |
A payoffs object. |
... |
Additional arguments (not used). |
A data.frame with one row per interaction cluster and the following columns:
Cluster label (as factor).
Mean of CD4 differences in the group.
Mean of viral load differences in the group.
Number of observations in the group.
set.seed(42)
data(cd_3)
cd_data <- cd_3[,-1]
cd_result <- cds_diff(cd_data)
data(vl_3)
vl_data <- vl_3[,-1]
vl_result <- vlogs_diff(vl_data)
result <- InteractionClassification(cd_result = cd_result, vl_result = vl_result)
summary(result)
set.seed(42)
data(cd_3)
cd_data <- cd_3[,-1]
cd_result <- cds_diff(cd_data)
data(vl_3)
vl_data <- vl_3[,-1]
vl_result <- vlogs_diff(vl_data)
result <- InteractionClassification(cd_result = cd_result, vl_result = vl_result)
data(preds)
payoffs_results <- estimate_payoffs(result, preds)
summary(payoffs_results)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.